package com.smcic.api.operate.service.impl;

import cn.hutool.core.date.DateTime;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.smcic.api.operate.entity.EnrollInfo;
import com.smcic.api.operate.mapper.EnrollInfoMapper;
import com.smcic.api.operate.service.IEnrollInfoService;
import com.smcic.api.operate.service.OSSService;
import org.apache.http.util.TextUtils;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author syj
 * @since 2022-12-10
 */
@Service
public class EnrollInfoServiceImpl extends ServiceImpl<EnrollInfoMapper, EnrollInfo> implements IEnrollInfoService {
    @Resource
    private OSSService ossService;

    @Resource
    private VoteInfoServiceImpl voteInfoService;

    public void store(String phone, String name, String university, String isOnLine, String type, Integer operateId, String introduction, String workTitle, MultipartFile file){

        String url = null;
        if(null != file){
            String path = "enroll/" + phone + "/" + (new DateTime().toString("yyyyMMddHHmmss")) + "/" + file.getOriginalFilename();
            ossService.put("smcic-index", path, file);

            url = "https://cxzx.smcic.net/" + path;
        }
        EnrollInfo enrollInfo = new EnrollInfo(phone, name, university, url, isOnLine, type, operateId, introduction, LocalDateTime.now(), workTitle);
        EnrollInfo one = lambdaQuery().eq(EnrollInfo::getPhone, phone).one();

        if (null != one){
//            BeanUtils.copyProperties(enrollInfo, one);
            one.setFile(enrollInfo.getFile());
            one.setName(enrollInfo.getName());
            one.setIntroduction(enrollInfo.getIntroduction());
            one.setUpdateTime(enrollInfo.getUpdateTime());
            one.setType(enrollInfo.getType());
            updateById(one);
        }else{
            save(enrollInfo);
        }
    }

    public List<EnrollInfo> list(String type, Integer operate, String phone){
        voteInfoService.lsVerify(phone);

        return lambdaQuery().eq(!TextUtils.isEmpty(type), EnrollInfo::getType, type).eq(EnrollInfo::getOperateId, operate)
                .eq(EnrollInfo::getStatus, 1)
                .orderByAsc(EnrollInfo::getSort).list();
    }

    public List<EnrollInfo> rank(String type, Integer operate, String phone){
        voteInfoService.lsVerify(phone);

        return lambdaQuery().eq(!TextUtils.isEmpty(type), EnrollInfo::getType, type).eq(EnrollInfo::getOperateId, operate)
                .eq(EnrollInfo::getStatus, 1)
                .orderByDesc(EnrollInfo::getVotes).list();
    }

}
